[Yt-svn] yt-commit r1661 - trunk/yt/lagos

sskory at wrangler.dreamhost.com sskory at wrangler.dreamhost.com
Sat Mar 13 14:57:09 PST 2010


Author: sskory
Date: Sat Mar 13 14:57:08 2010
New Revision: 1661
URL: http://yt.enzotools.org/changeset/1661

Log:
RMS Velocity is in code units.

Modified:
   trunk/yt/lagos/HaloFinding.py

Modified: trunk/yt/lagos/HaloFinding.py
==============================================================================
--- trunk/yt/lagos/HaloFinding.py	(original)
+++ trunk/yt/lagos/HaloFinding.py	Sat Mar 13 14:57:08 2010
@@ -125,7 +125,7 @@
     def rms_velocity(self):
         """
         Returns the mass-weighted RMS velocity for the halo
-        particles in code units.
+        particles in cgs units.
         """
         bv = self.bulk_velocity()
         pm = self["ParticleMassMsun"]
@@ -382,7 +382,7 @@
 
     def rms_velocity(self):
         """
         Returns the RMS velocity for the halo particles in code units.
         """
         if self.rms_vel is not None:
             return self.rms_vel
@@ -382,7 +382,7 @@
     def rms_velocity(self):
         """
-        Returns the RMS velocity for the halo particles in code units.
+        Returns the RMS velocity for the halo particles in cgs units.
         """
         if self.rms_vel is not None:



More information about the yt-svn mailing list